@@ -12,7 +12,8 @@ clean_data_path <- function(root, file, normalize = TRUE) {
   assert_that(is.flag(normalize), noNA(normalize))
   dir_name <- dirname(file)
   assert_that(
-    length(grep("\\.\\.", dir_name)) == 0, msg = "file should not contain '..'"
+    length(grep("\\.\\.", dir_name)) == 0,
+    msg = "file should not contain '..'"
   )
 
   file <- gsub("\\..*$", "", basename(file))
