@@ -2,7 +2,10 @@ test_that("verify_vc", {
   root <- tempfile(pattern = "git2rdata-verify-vc")
   dir.create(root)
   write_vc(
-    x = test_data, file = "test.txt", root = root, sorting = "test_integer",
+    x = test_data,
+    file = "test.txt",
+    root = root,
+    sorting = "test_integer",
     digits = 6
   )
   expect_s3_class(
@@ -11,7 +14,9 @@ test_that("verify_vc", {
   )
   expect_s3_class(
     verify_vc(
-      "test.txt", root = root, variables = c("test_numeric", "test_logical")
+      "test.txt",
+      root = root,
+      variables = c("test_numeric", "test_logical")
     ),
     "data.frame"
   )
