@@ -1,7 +1,8 @@
 test_that("description", {
   expect_error(
     update_metadata(
-      file = "test", root = data.frame()
+      file = "test",
+      root = data.frame()
     ),
     "a 'root' of class data.frame is not supported"
   )
@@ -11,7 +12,10 @@ test_that("description", {
 
   expect_is(
     write_vc(
-      x = test_data, file = "test.txt", root = root, sorting = "test_Date",
+      x = test_data,
+      file = "test.txt",
+      root = root,
+      sorting = "test_Date",
       digits = 6
     ),
     "character"
@@ -19,17 +23,22 @@ test_that("description", {
 
   expect_type(
     update_metadata(
-      file = "test", root = root, field_description = c(
-        test_character = "Some information", test_factor = "Some information",
+      file = "test",
+      root = root,
+      field_description = c(
+        test_character = "Some information",
+        test_factor = "Some information",
         test_integer = "Some information"
       )
     ),
     "character"
   )
 
-  expect_is({
+  expect_is(
+    {
       output <- read_vc("test", root = root)
-    }, "git2rdata"
+    },
+    "git2rdata"
   )
   expect_true(assertthat::has_attr(output$test_character, "description"))
   expect_true(assertthat::has_attr(output$test_factor, "description"))
@@ -52,15 +61,20 @@ test_that("description", {
 
   expect_type(
     update_metadata(
-      file = "test", root = root, name = "my_table", title = "My Table",
+      file = "test",
+      root = root,
+      name = "my_table",
+      title = "My Table",
       description = "This is description for the unit tests",
       field_description = c(test_character = NA, test_factor = "")
     ),
     "character"
   )
-  expect_is({
+  expect_is(
+    {
       output <- read_vc("test", root = root)
-    }, "git2rdata"
+    },
+    "git2rdata"
   )
   expect_false(assertthat::has_attr(output$test_character, "description"))
   expect_false(assertthat::has_attr(output$test_factor, "description"))
@@ -74,26 +88,32 @@ test_that("description", {
 
   expect_is(current_status <- status(root), "git_status")
   expect_equal(
-    unname(unlist(current_status$untracked)), c("test.tsv", "test.yml")
+    unname(unlist(current_status$untracked)),
+    c("test.tsv", "test.yml")
   )
   expect_equal(unname(current_status$staged), list())
 
   expect_type(
     update_metadata(
-      file = "test", root = root, name = "staged_table", title = "Staged table",
-      description = "This is description for the unit tests", stage = TRUE,
+      file = "test",
+      root = root,
+      name = "staged_table",
+      title = "Staged table",
+      description = "This is description for the unit tests",
+      stage = TRUE,
       field_description = c(test_character = NA, test_factor = "")
     ),
     "character"
   )
-  expect_is({
-    output <- read_vc("test", root = root)
-  }, "git2rdata"
+  expect_is(
+    {
+      output <- read_vc("test", root = root)
+    },
+    "git2rdata"
   )
   expect_output(display_metadata(output), "Table name: staged_table")
 
   expect_is(current_status <- status(root), "git_status")
   expect_equal(unname(unlist(current_status$untracked)), "test.tsv")
   expect_equal(unname(unlist(current_status$staged)), "test.yml")
-
 })
